@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Moose;
 use Moose::Util::TypeConstraints qw(enum);
@@ -85,6 +85,7 @@ sub add_badges {
 
     my $distname = $self->zilla->name;
     my $distmeta = $self->zilla->distmeta;
+    my $dist_version = $self->zilla->version;
     my $repository = $distmeta->{resources}->{repository}->{url};
     return unless $repository;
     my ($base_url, $user_name, $repository_name) = ($repository =~ m{^\w+://(.*)/([^\/]+)/(.*?)(\.git|\/|$)});
@@ -124,6 +125,8 @@ sub add_badges {
             push @badges, "[![Docker Build Status](https://img.shields.io/docker/build/\L$user_name/$repository_name\E.svg)](https://hub.docker.com/r/\L$user_name/$repository_name\E/)";
         } elsif ($badge =~ m{^github_actions/(.+)}) {
             push @badges, "[![Actions Status](https://github.com/$user_name/$repository_name/workflows/$1/badge.svg)](https://github.com/$user_name/$repository_name/actions)";
+        } elsif ($badge eq 'cpancover') {
+            push @badges, "[![CPAN Cover Status](https://cpancoverbadge.perl-services.de/$distname-$dist_version)](https://cpancoverbadge.perl-services.de/$distname-$dist_version)";
         }
     }
 
@@ -177,6 +180,7 @@ Dist::Zilla::Plugin::GitHubREADME::Badge - Dist::Zilla - add badges to github RE
     badges = docker_automated
     badges = docker_build
     badges = github_actions/test
+    badges = cpancover
     place = bottom
     phase = release
 
